.. _orm_internal_toplevel:

ORM Internals
=============

Some key internal constructs are listed here.

.. currentmodule: sqlalchemy.orm

.. autoclass:: sqlalchemy.orm.instrumentation.ClassManager
    :members:
    :show-inheritance:

.. autoclass:: sqlalchemy.orm.properties.ColumnProperty
    :members:
    :show-inheritance:

.. autoclass:: sqlalchemy.orm.descriptor_props.CompositeProperty
    :members:
    :show-inheritance:

.. autoclass:: sqlalchemy.orm.state.InstanceState
    :members:
    :show-inheritance:

.. autoclass:: sqlalchemy.orm.interfaces.MapperProperty
    :members:
    :show-inheritance:

.. autoclass:: sqlalchemy.orm.interfaces.PropComparator
    :members:
    :show-inheritance:

.. autoclass:: sqlalchemy.orm.properties.RelationshipProperty
    :members:
    :show-inheritance:


.. autoclass:: sqlalchemy.orm.descriptor_props.SynonymProperty
    :members:
    :show-inheritance:

.. autoclass:: sqlalchemy.orm.query.QueryContext
    :members:
    :show-inheritance:
